.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://api.cirrus-ci.com/github/<USER>/stelar_client.svg?branch=main
        :alt: Built Status
        :target: https://cirrus-ci.com/github/<USER>/stelar_client
    .. image:: https://readthedocs.org/projects/stelar_client/badge/?version=latest
        :alt: ReadTheDocs
        :target: https://stelar_client.readthedocs.io/en/stable/
    .. image:: https://img.shields.io/coveralls/github/<USER>/stelar_client/main.svg
        :alt: Coveralls
        :target: https://coveralls.io/r/<USER>/stelar_client
    .. image:: https://img.shields.io/pypi/v/stelar_client.svg
        :alt: PyPI-Server
        :target: https://pypi.org/project/stelar_client/
    .. image:: https://img.shields.io/conda/vn/conda-forge/stelar_client.svg
        :alt: Conda-Forge
        :target: https://anaconda.org/conda-forge/stelar_client
    .. image:: https://pepy.tech/badge/stelar_client/month
        :alt: Monthly Downloads
        :target: https://pepy.tech/project/stelar_client
    .. image:: https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter
        :alt: Twitter
        :target: https://twitter.com/stelar_client

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

.. image:: https://readthedocs.org/projects/stelar-client/badge/?version=latest
    :alt: ReadTheDocs
    :target: https://stelar-client.readthedocs.io/en/stable/

.. image:: https://img.shields.io/pypi/v/stelar-client.svg
    :alt: PyPI-Server
    :target: https://pypi.org/project/stelar-client/

=============
stelar_client
=============


    A client for working with the STELAR KLMS.


The STELAR Knowledge Lake Management System (KLMS) is a state-of-the-art data
management system that allows users to store, retrieve, and manage data in a
scalable and efficient manner. The STELAR KLMS implements many of the features
of a modern data lake, combined with strong support for metadata collection,
advanced metadata search, data governance, and data quality assurance.

The STELAR KLMS is developed by a consortium of research institutions and industry
partners as part of the STELAR project, which is funded by the European Union's
Horizon 2020 research and innovation programme. 
You can find more information about the STELAR KLMS in this `link <https://stelar.eu/>`_.


.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.6. For details and usage
information on PyScaffold see https://pyscaffold.org/.
